#
# spec file for package python-jupyterlab-server
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

Name:           python-jupyterlab-server%{psuffix}
Version:        2.25.2
Release:        2.1
Summary:        Server components for JupyterLab and JupyterLab-like applications
License:        BSD-3-Clause
URL:            https://github.com/jupyterlab/jupyterlab_server
Source:         https://files.pythonhosted.org/packages/source/j/jupyterlab_server/jupyterlab_server-%{version}.tar.gz
Source100:      python-jupyterlab-server-rpmlintrc
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling >= 1.7}
BuildRequires:  %{python_module pip}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Babel >= 2.10
Requires:       python-Jinja2 >= 3.0.3
Requires:       python-json5 >= 0.9.0
Requires:       python-jsonschema >= 4.18
Requires:       python-packaging >= 21.3
Requires:       python-requests >= 2.31
Requires:       (python-jupyter-server >= 1.21 with python-jupyter-server < 3)
%if 0%{?python_version_nodots} < 310
Requires:       python-importlib-metadata >= 4.8.3
%endif
Provides:       python-jupyterlab_server = %{version}-%{release}
Obsoletes:      python-jupyterlab_server < %{version}-%{release}
Provides:       python-jupyter-jupyterlab-server = %{version}-%{release}
Obsoletes:      python-jupyter-jupyterlab-server < %{version}-%{release}
Provides:       python-jupyter_jupyterlab_server = %{version}-%{release}
Obsoletes:      python-jupyter_jupyterlab_server < %{version}-%{release}
Provides:       python-jupyter_jupyterlab_launcher = %{version}-%{release}
Obsoletes:      python-jupyter_jupyterlab_launcher < %{version}-%{release}
BuildArch:      noarch
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
Provides:       jupyter-jupyterlab-launcher = %{version}-%{release}
Obsoletes:      jupyter-jupyterlab-launcher < %{version}-%{release}
Provides:       jupyter-jupyterlab_launcher = %{version}-%{release}
Obsoletes:      jupyter-jupyterlab_launcher < %{version}-%{release}
Provides:       jupyter-jupyterlab-server = %{version}-%{release}
Obsoletes:      jupyter-jupyterlab-server < %{version}-%{release}
Provides:       jupyter-jupyterlab_server = %{version}-%{release}
Obsoletes:      jupyter-jupyterlab_server < %{version}-%{release}
%endif
%if %{with test}
BuildRequires:  %{python_module jupyterlab-server-test = %{version}}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
%endif
%python_subpackages

%description
JupyterLab Server sits between JupyterLab and Jupyter Server,
and provides a set of REST API handlers and utilities that are
used by JupyterLab. It is a separate project in order to
accommodate creating JupyterLab-like applications from a more
limited scope.

%package test
Summary:        The jupyterlab_server[test] requirements
Requires:       python-Werkzeug
Requires:       python-ipykernel
Requires:       python-pytest >= 7
Requires:       python-pytest-console-scripts
Requires:       python-pytest-jupyter-server >= 0.6.2
Requires:       python-pytest-timeout
Requires:       python-requests-mock
Requires:       (python-openapi-spec-validator >= 0.6 with python-openapi-spec-validator < 0.8)
#Requires:       python-sphinxcontrib-spelling
Requires:       python-strict-rfc3339
Requires:       python-jupyterlab-server = %{version}
Requires:       python-ruamel.yaml
%if %{python_version_nodots} < 312
Requires:       (python-openapi-core >= 0.18 with python-openapi-core < 0.19)
%endif

%description test
Metapackage for the jupyterlab_server[test] requirement specifier
without code coverage.

%package openapi
Summary:        The jupyterlab_server[openapi]] extra
Requires:       python-jupyterlab-server = %{version}
Requires:       python-ruamel.yaml
Requires:       (python-openapi-core >= 0.18 with python-openapi-core < 0.19)

%description openapi
Metapackage for the jupyterlab_server[openapi] extra

%prep
%autosetup -p1 -n jupyterlab_server-%{version}
sed -i 's/, "--color=yes"//' pyproject.toml

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
export PYTHONDONTWRITEBYTECODE=1
# no openapi-core in python312
python312_ignoretests="--ignore tests/test_labapp.py"
python312_ignoretests="$python312_ignoretests --ignore tests/test_listings_api.py"
python312_ignoretests="$python312_ignoretests --ignore tests/test_settings_api.py"
python312_ignoretests="$python312_ignoretests --ignore tests/test_themes_api.py"
python312_ignoretests="$python312_ignoretests --ignore tests/test_translation_api.py"
python312_ignoretests="$python312_ignoretests --ignore tests/test_workspaces_api.py"
%{python_expand # https://github.com/jupyterlab/jupyterlab_server/issues/390
$python -m venv build/testenv --system-site-packages
for p in \
  tests/translations/jupyterlab-some-package \
  tests/translations/jupyterlab-language-pack-es_CO
do
  build/testenv/bin/pip install --use-pep517 --no-build-isolation --disable-pip-version-check $p
done
build/testenv/bin/python -m pytest -v ${$python_ignoretests}
}
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/jupyterlab_server
%{python_sitelib}/jupyterlab_server-%{version}.dist-info

%files %{python_files test}
%license LICENSE

%if %{python_version_nodots} < 312
%files %{python_files openapi}
%license LICENSE
%endif
%endif

%changelog
* Tue Feb  6 2024 Ben Greiner <code@bnavigator.de>
- Disable openapi subpackage and tests for python312: not supported
  yet
* Sun Nov 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.25.2
  * Maintenance and upkeep improvements
- Release 2.25.1
  * Add repository info when getting federated extensions #417
    (@nbowditch-einblick)
* Wed Sep 13 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.25.0
  * Bump openapi deps and support Python 3.8-3.12 #410 (@blink1073)
* Sun Jul 30 2023 Ben Greiner <code@bnavigator.de>
- Drop jupyterlab_server-ignore-jsonschema-deprecation.patch
* Sat Jul 29 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.24.0
  * add lab config for copy absolute path #405 (@pauky)
  * Requirements updates
- Disable openapi subpackage: gh#jupyterlab/jupyterlab_server#400
- Ignore jsonschema deprecation
  * Add jupyterlab_server-ignore-jsonschema-deprecation.patch
* Thu Jul 20 2023 Ben Greiner <code@bnavigator.de>
- Raise upper pin for openapi-spec-validator
  * gh#jupyterlab/jupyterlab_server#403
* Tue Jun 13 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.23.0
  * Set Cache-control immutable for static files #394 (@brichet)
- Make sure to supply the language test packages for tests
* Sun Apr 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.22.1
  * Fix coverage handling (#392 #392 (@blink1073)
- Release 2.22.0
  * Optional argument to get only the schema names #385 (@brichet)
- Release 2.21.0
  * Add json5 support for page_config.json #388 (@peytondmurray)
  * Ignore warning from bind_sockets #383 (@blink1073)
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.20.0
  * Change periodic callback time from tuple to int #376 (@rmoe)
  * Pin openapi deps #381 (@blink1073)
  * Add more linting #369 (@blink1073)
  * Clean up openapi compat and warnings #368 (@blink1073)
* Mon Jan 16 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.19.0
  * Don't change language environment variable #366 (@fcollonval)
  * Fix test_process_app #367 (@blink1073)
  * Sync lint deps #365 (@blink1073)
* Sun Jan  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.18.0
  * Prepare for jupyter_server preferred_dir fix #324 (@vidartf)
  * Handle systems with python3 #362 (@blink1073)
- Drop jupyterlab-server-pr362-entrypoint.patch
* Tue Dec 27 2022 Ben Greiner <code@bnavigator.de>
- Update ot 2.17.0
  * Do not repeat requirements #361 (@blink1073)
  * Add support for newer openapi spec #360 (@blink1073)
  * Add spelling and docstring enforcement #358 (@blink1073)
- Release 2.16.6
  * Restore print outputs in process #357 (@blink1073)
- Release 2.16.5
  * Use pytest-jupyter #351 (@blink1073)
- Release 2.16.4
  * Add py.typed marker file #349 (@blink1073)
- Release 2.16.3
  * Fix handling of jupyter core warning #335 (@blink1073)
- Release 2.16.2
  * Terminals availability is not the responsibility of JupyterLab
    [#330] (@fcollonval)
- Add jupyterlab-server-pr362-entrypoint.patch
- Rename main package to python-jupyterlab-server
- Test in multibuild
* Wed Oct 26 2022 Ben Greiner <code@bnavigator.de>
- Update to 2.16.1
  * Prep for using releaser #327 (@blink1073)
  * Maintenance cleanup #325 (@blink1073)
  * Fix workflows and add new ones #318 (@fcollonval)
- Release 2.16.0
  * raise jupyter_server pin to include 2.x #302 (@Zsailer)
  * CI Cleanup #316 (@blink1073)
  * Ignore warnings in prerelease test #312 (@blink1073)
- Drop jupyterlab-server-fix-testing.patch
* Thu Oct 13 2022 Ben Greiner <code@bnavigator.de>
- update to 2.15.2
  * Pin openapi_core dependency #308 (@blink1073)
- Disable openapi tests, as openapi-core 0.15.x is not compatible
  * gh#jupyterlab/jupyterlab_server#308
* Mon Sep 26 2022 Ben Greiner <code@bnavigator.de>
- update to 2.15.1
  * Ignore deprecationwarning from jsonschema #295 (@blink1073)
- update jupyterlab-server-fix-testing.patch: mistune no longer
  vendored in nbconvert.
* Fri Aug  5 2022 Ben Greiner <code@bnavigator.de>
- Update to 2.15.0
  * Suppress tornado 6.2 beta warnings #285 (@blink1073)
  * Add compat for openapi-core 0.15 #281 (@blink1073)
- Release 2.14.0
  * proper setup for the fallback logger #269 (@rvalieris)
  * Switch to hatch backend #274 (@blink1073)
- Release 2.13.0
  * Audit uses of print #261 (@blink1073)
  * Switch to importlib.metadata to list entry points #264
    (@fcollonval)
  * Add git-blame-ignore-revs #258 (@blink1073)
- Release 2.12.0
  * Make openapi optional and lazy #253 (@blink1073)
  * Adds notebook_starts_kernel option to make "canStartKernel"
    configurable #248 (@jweill-aws)
  * Clean up tests and add public openapi_spec #247 (@blink1073)
- Release 2.11.2
  * Resolve paths in tests #245 (@blink1073)
- Release 2.11.1
  * Restore pytest_plugin #243 (@blink1073)
- Release 2.11.0
  * Also look in static for license files #238 (@bollwyvl)
- Add jupyterlab-server-fix-testing.patch
* Fri Dec 31 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.10.2
  * Revert "Delay list -> dict conversation to end (#192)" #234
    (@blink1073)
  * Fix issue where preferredPath is incorrectly calculated #233
    (@mlucool) Maintenance and upkeep improvements
  * Add downstream test workflow #232 (@blink1073)
- Release 2.10.1
  * Restore back older export for workspaces #229 (@fcollonval)
- Release 2.10.0
  * Move workspace management in jupyterlab_server #227
    (@fcollonval)
  * Delay list -> dict conversation to end #192 (@vidartf)
- Release 2.9.0
  * Add overrides.d for settings defaults #224 (@bollwyvl)
  * Add page_config_hook #220 (@minrk)
  * Enforce labels on PRs #221 (@blink1073)
  * Fix caching of conda env in CI #218 (@blink1073)
  * pyproject.toml: clarify build system version #222
    (@adamjstewart)
- Fix import of mistune in tests due to our mitigation of
  gh#jupyter/nbconvert#1685
* Sun Oct 17 2021 Ben Greiner <code@bnavigator.de>
- Really update to 2.8.2 (was 2.8.1 before)
  * Fallback to context-less translation on Python 3.7 #213
    (@krassowski)
  * Clean unneeded catch #210 (@fcollonval)
* Fri Sep 17 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.8.2
  * Fall back to DEFAULT_LOCALE when translation settings schema is
    invalid in get_current_locale
  * Translate settings schema
- Really remove the patch jupyterlab-server-pr198-openapi014.patch
* Mon Sep  6 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.7.2
  * Do not overwrite capitalization of region names #202
  * Use Check Links Action #201
  * Recommend pytest --pyargs jupyterlab_server #203
- Changlog for release 2.7.1
  * Fix reset user settings if validation failed #199
  * support openapi-core 0.14 SpecPath #198
- Drop jupyterlab-server-pr198-openapi014.patch merged upstream
  * gh#jupyterlab/jupyterlab_server#198
- Fix jupyter-jupyterlab-server-rpmlintrc for rpmlint 2 errors
- All the test exceptions have been resolved upstream
* Mon Aug 16 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.7.0
  * Switch to entrypoints package #187
- Changelog for release 2.6.2
  * PR: Add preferred dir option to config #190
  * PR: Update new_defaults dictionary instead of copy #194
  * Update tests workflow #193
- Changelog for release 2.6.1
  * Merge overrides settings if values are dicts #188
- Changelog for release 2.6.0
  * LicensesManager and API/CLI #161
- Changelog for release 2.5.1
  * Maintenance and upkeep improvements
  * Remove Packaging Dependency #181
- Changelog for release 2.5.0
  * Support for overrides.json5 #179
  * Documentation improvements
  * Make LabConfig configurable and add config API docs #172
  * Upgrade packaging #178
  * Add more API docs #177
  * Add cli config options documentation #176
  * Add example request/responses to REST docs #174
  * Add Swagger Docs #173
  * Update Readme Badges #171
- Changelog for release 2.4.0
  * Add Sphinx docs #169
  * Cleanup unused imports #165
  * Fill in missing changelog entries #164
  * Improve documentation: Instructions for development and test
    setups #130
- Changelog for release 2.3.0
  * Set file_url_prefix trait for opening notebooks directly #162
- Changelog for release 2.2.1
  * Alleviate invalid locale issue by only setting it if language
    pack exists #159
- Changelog for release 2.2.0
  * Add URL and description for federated extension data #154
- Changelog for release 2.1.5
  * Fix/cp949 encoding error #158
- Changelog for release 2.1.4
  * Reduce path length of installed package #157 (@afshin)
- Changelog for release 2.1.3
  * Fix mathjax URL handling #153
- Add jupyterlab-server-pr198-openapi014.patch for new API in
  openapi-core >= 0.14
* Mon Feb  1 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.1.3
  * no upstream changelog (No really!)
- Make singlespec
- Update requirements, providers and obsoletions
* Sun May 24 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.5:
  * Clean up terminate logic. #91
  * Kill the subprocess if it does not stop. #86
  * Do not try to close the watch process file handle. #85
  * Update nodejs error message to not give an outdated version. #84
* Tue Aug 20 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.0.6
  * Add .json.orig files to sdists
- Disable spurious rpmlint checks.
  They are incorrectly flagging valid test files.
  These tests are used by other packages besides this one,
  so they need to stay in.
* Tue Aug 20 2019 Todd R <toddrme2178@gmail.com>
- This replaces jupyterlab-launcher
* Sat Jul 27 2019 Todd R <toddrme2178@gmail.com>
- Update to 1.0.5
  * require jinja2 to make tojson always safe
- Update to 1.0.4
  * use escape instead of urlencode for urls
- Update to 1.0.3
  * Escape template values in Jinja
- Update to 1.0.2
  * Add store ID to page config
- Update to 1.0.1
  * fix page config escaping
- Update to 1.0.0
  * jupyterlab 1.0.0 support
* Thu May 16 2019 Todd R <toddrme2178@gmail.com>
- Fix conflict with newer version on openSUSE:Factory
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Roll back to version 0.2.0, jupyterlab is not compatible with 0.3.0.
- Rename to to match jupyter package naming guidelines.
* Mon Mar 11 2019 Todd R <toddrme2178@gmail.com>
- Simplify files somewhat
- Grammar fix in summary
* Sat Mar  2 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * remove devel from noarch
  * be more specific in %%files section
- update to version 0.3.0:
  * Update workspaces listing to include values.
* Mon Jan  7 2019 Todd R <toddrme2178@gmail.com>
- Initial version (0.2.0)
